##################################################
# do not change this file, real File is [run.py] #
##################################################
import argparse
import subprocess
import os
from run import *

parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter)
parser.add_argument("--run", type=str, default=None, help=("input param file path"))
parser.add_argument("--out", type=str, default=None, help=("output file path"))
cmd_opts = parser.parse_args()


def main(cmd_opts):
    if cmd_opts.run == None or cmd_opts.out == None:
        print("args fail!")
        return
    
    if os.path.exists(cmd_opts.run):
        with open(cmd_opts.run, 'r') as f:
            data = json.load(f)
    result = runTask(data)
    with open(cmd_opts.out, 'w') as f:
        json.dump(result, f)

if __name__ == '__main__':
    subprocess.run(f"mecord widget add {os.getcwd()}", stdout=None)
    main(cmd_opts)



(function(n,t){var u={generalPost:1,post:2,preview:3},f={image:1,video:2,audio:3,text:4},i={version:"1.1.1",msgQueue:[],callbackCache:[],callbackId:0,processingMsg:!1},r;i.create=function(){i.bridgeIframe=document.createElement("iframe");i.bridgeIframe.style.display="none";document.documentElement.appendChild(i.bridgeIframe)};i.getCallbackId=function(){return i.callbackId++};i.prepareProcessingMessages=function(){i.processingMsg=!0};i.fetchMessages=function(){if(i.msgQueue.length>0){var n=JSON.stringify(i.msgQueue);return i.msgQueue.length=0,n}return i.processingMsg=!1,null};i.onCallback=function(n,t){i.callbackCache[n]&&i.callbackCache[n](t)};i.formatParams=function(n){var t=JSON.parse(n);return t.postType=u[t.postType]||1,t.taskType=f[t.taskType]||1,JSON.stringify(t)};i.onPushH5=function(n){r.emit("onProgress",n)};i.callNative=function(r,u,f,e){var o={},s;o.clz=r;o.method=u;f!=t&&(o.args=f);e&&(s=i.getCallbackId(),i.callbackCache[s]=e,console.log(o),o.args?o.args.callbackId=s.toString():o.args={callbackId:s.toString()});n.jsBridgeChannelApi&&n.jsBridgeChannelApi.postMessage(JSON.stringify(o))};i.invoke=function(n,t,r,u){if(Object.prototype.toString.call(n)==="[object Object]"?(t=n.method,r=n.args||{},u=n.callback||null,n=n.clz||"jsBridgeChannelApi"):(n=n||"jsBridgeChannelApi",r=r||{}),u){i.callNative(n,t,r,u);return}i.callNative(n,t,r);return};r={eventList:{},on:function(n,t){return(r.eventList[n]||(r.eventList[n]=[])).push(t),r},emit:function(){var i=[].shift.call(arguments),t=[],n,u;if(!r.eventList[i])return!1;for(n=0;n<r.eventList[i].length;n++)t.push(r.eventList[i][n]);if(!t||t.length===0)return!1;for(n=0;n<t.length;n++)u=t[n],u.apply(r,arguments);return r},excuting:function(n,t){return i.invoke({method:"excuting",args:{data:i.formatParams(n)},callback:t})},pickImage:function(n){return i.invoke({method:"uploadReportImage",callback:n})}};console.log("%cMecordJS","color:#B2A0F4",i.version);n.ApiBridge=i;n.MekongJS=r;n.MecordJS=r})(window);


# import socket
# import time
# import threading

# SERVER_ADDRESS = ('localhost', 12345)
# HEARTBEAT_INTERVAL = 1

# # 定义消息类型
# MESSAGE_TYPE_HEARTBEAT = 0
# MESSAGE_TYPE_DATA = 1

# class MecordSocket:

#     def _loop(self):
#         threading.Timer(HEARTBEAT_INTERVAL, self._heartBeat).start()

#     def __init__(self, cb):
#         self.callback = cb
#         self.is_connecting = False
#         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

#     def start(self, count = 5):
#         try:
#             self.sock.connect(SERVER_ADDRESS)
#             self.is_connecting = True
#             print('Connected to server at', SERVER_ADDRESS)
#             self._loop()
#         except (socket.error, ConnectionError) as e:
#             if count > 0:
#                 print('Error:', e)
#                 print('Retrying in 5 seconds...')
#                 threading.Timer(5, self.start, (count-1,)).start()
#             else:
#                 self.is_connecting = False
#                 print('connect fail!')
#         except Exception as e:
#             print('Error:', e)
    
#     def isRunning(self):
#         return self.is_connecting

#     def _heartBeat(self):
#         if self.is_connecting == False:
#             return
        
#         try:
#             # 发送心跳消息
#             heartbeat_msg = b'\x00'  # 使用字节0表示心跳消息
#             self.sock.sendall(heartbeat_msg)
#             print('Sent heartbeat at', time.time())
            
#             # 等待接收消息
#             data = self.sock.recv(1024)
#             if data:
#                 message_type = data[0]
#                 if message_type == MESSAGE_TYPE_DATA:
#                     # 如果收到数据消息，则调用回调函数处理数据
#                     data = data[1:].decode('utf-8')
#                     self.callback(data)
#         except Exception as e:
#             print('Error:', e)
#         self._loop()

#     def sendData(self, data):
#         if self.is_connecting == False:
#             return
        
#         try:
#             data_msg = b'\x01' + data.encode('utf-8')  # 使用字节1表示数据消息
#             self.sock.sendall(data_msg)
#             print('Sent data at', time.time())
#         except Exception as e:
#             print('Error:', e)

#     def close(self):
#         if self.is_connecting == False:
#             return
        
#         try:
#             self.timer.close()
#             print('Closing connection')
#             self.sock.close()
#         except Exception as e:
#             print('Error:', e)
        



import json
import hashlib
import time
import requests

from mecord import uauth_common_pb2 
from mecord import uauth_ext_pb2 
from mecord import common_ext_pb2 
from mecord import aigc_ext_pb2 
from mecord import rpcinput_pb2 
from mecord import store 
from mecord import utils 
from mecord import constant 

uuid = utils.generate_unique_id()

def _aigc_post(request, function):
    return _post(url="https://mecord-beta.2tianxin.com/proxymsg", 
                 objStr="mecord.aigc.AigcExtObj", 
                 request=request, 
                 function=function)
    
def _common_post(request, function):
    return _post(url="https://beta.xiaohuxi.cn/proxymsg", 
                 objStr="mizacommon.uauth.AuthExtObj", 
                 request=request, 
                 function=function)
    
def _post(url, objStr, request, function):
    req = request.SerializeToString()
    opt = {
        "lang": "zh-Hans",
        "region": "CN",
        "appid": "80",
        "application": "mecord",
        "version": "1.0",
        "X-Token": store.token(),
        "uid": "1",
    }
    input_req = rpcinput_pb2.RPCInput(obj=objStr, func=function, req=req, opt=opt)
    res = requests.post(url=url, data=input_req.SerializeToString())
    pb_rsp = rpcinput_pb2.RPCOutput()
    pb_rsp.ParseFromString(res.content)
    if pb_rsp.ret == 0:
        return 0, "", pb_rsp.rsp
    else:
        # print(pb_rsp)
        return pb_rsp.ret, pb_rsp.desc, "" 
    

def GetQrcodeLoginCode():
    req = uauth_ext_pb2.GetQrcodeLoginCodeReq()
    req.login_type = uauth_common_pb2.UauthLoginType.LT_QRCODE_SCAN
    req.device_type = uauth_common_pb2.UauthDeviceType.DT_WINDOWS_PC
    req.device_id = uuid
    req.u_meng_device_id = ""

    rsp = uauth_ext_pb2.GetQrcodeLoginCodeRes()
    r1, r2, r3 = _common_post(req, "GetQrcodeLoginCode")
    if r1 != 0:
        print(r2)
        return None
    rsp.ParseFromString(r3)
    s = rsp.login_code
    return s

def CheckLoginLoop(code):
    req = uauth_ext_pb2.GetQrcodeLoginStatusReq()
    req.login_code = code
    req.device_id = uuid
    req.u_meng_device_id = ""

    rsp = uauth_ext_pb2.GetQrcodeLoginStatusRes()
    r1, r2, r3 = _common_post(req, "GetQrcodeLoginStatus")
    if r1 != 0:
        print(r2)
        return 0
    rsp.ParseFromString(r3)
    if rsp.status == uauth_ext_pb2.GetQrcodeLoginStatus.SUCCESS:
        sp = store.Store()
        data = sp.read()
        data["uid"] = rsp.commonSignInRes.user_id
        data["token"] = rsp.commonSignInRes.login_token
        data["nickname"] = rsp.userNickname
        data["icon"] = rsp.userIconUrl
        sp.write(data)
        return 1
    elif rsp.status == uauth_ext_pb2.GetQrcodeLoginStatus.EXPIRED or rsp.status == uauth_ext_pb2.GetQrcodeLoginStatus.CANCEL:
        return 0
    else:
        return -1
    
def GetTask(token):
    req = aigc_ext_pb2.GetTaskReq()
    req.version = constant.app_version
    req.DeviceKey = uuid
    map = store.widgetMap()
    for it in map:
        req.widgets.append(it)
    req.token = token
    req.limit = 1
    extInfo = store.readDeviceInfo()
    extInfo["app_version"] = constant.app_version
    extInfo["app_bulld_number"] = constant.app_bulld_number
    extInfo["app_name"] = constant.app_name
    req.extend = json.dumps(extInfo)

    rsp = aigc_ext_pb2.GetTaskRes()
    r1, r2, r3 = _aigc_post(req, "GetTask")
    if r1 != 0:
        print(r2)
        return []
    rsp.ParseFromString(r3)
    datas = []
    for it in rsp.list:
        datas.append({
            "taskUUID": it.taskUUID,
            "pending_count": rsp.count - rsp.limit,
            "config": it.config,
            "data": it.data,
        })
    return datas

def TaskNotify(taskUUID, status, msg, dataStr):
    req = aigc_ext_pb2.TaskNotifyReq()
    req.version = constant.app_version
    req.taskUUID = taskUUID
    if status:
        req.taskStatus = common_ext_pb2.TaskStatus.TS_Success
    else:
        req.taskStatus = common_ext_pb2.TaskStatus.TS_Failure
    req.failReason = msg
    req.data = dataStr

    rsp = aigc_ext_pb2.TaskNotifyRes()
    r1, r2, r3 = _aigc_post(req, "TaskNotify")
    if r1 != 0:
        print(r2)
        return False
    rsp.ParseFromString(r3)
    return True

def GetAigcDeviceInfo():
    req = aigc_ext_pb2.AigcDeviceInfoReq()
    req.version = constant.app_version
    req.deviceKey = uuid

    rsp = aigc_ext_pb2.AigcDeviceInfoRes()
    r1, r2, r3 = _aigc_post(req, "DeviceInfo")
    if r1 != 0:
        print(r2)
        return False
    rsp.ParseFromString(r3)
    
    if len(rsp.groupUUID) > 0:
        sp = store.Store()
        data = sp.read()
        data["groupUUID"] = rsp.groupUUID
        data["token"] = rsp.token
        if rsp.isCreateWidget == True:
            data["isCreateWidget"] = rsp.isCreateWidget
        sp.write(data)
        return True
    return False

def CreateWidgetUUID():
    req = aigc_ext_pb2.CreateWidgetReq()
    rsp = aigc_ext_pb2.CreateWidgetRes()
    r1, r2, r3 = _aigc_post(req, "CreateWidget")
    if r1 != 0:
        print(r2)
        return ""
    rsp.ParseFromString(r3)
    return rsp.widgetUUID

def GetOssUrl(ext):
    req = aigc_ext_pb2.UploadFileUrlReq()
    req.token = store.token()
    req.version = constant.app_version
    req.fileExt = ext

    rsp = aigc_ext_pb2.UploadFileUrlRes()
    r1, r2, r3 = _aigc_post(req, "UploadFileUrl")
    if r1 != 0:
        print(r2)
        return ""
    rsp.ParseFromString(r3)
    return rsp.url, rsp.contentType
    
def GetWidgetOssUrl(widgetid):
    req = aigc_ext_pb2.UploadWidgetUrlReq()
    req.version = constant.app_version
    req.widgetUUID = widgetid

    rsp = aigc_ext_pb2.UploadWidgetUrlRes()
    r1, r2, r3 = _aigc_post(req, "UploadWidgetUrl")
    if r1 != 0:
        print(r2)
        return ""
    rsp.ParseFromString(r3)
    return rsp.url, rsp.contentType

def WidgetUploadEnd(url):
    req = aigc_ext_pb2.UploadWidgetReq()
    req.version = constant.app_version
    req.fileUrl = url
    
    rsp = aigc_ext_pb2.UploadWidgetRes()
    r1, r2, r3 = _aigc_post(req, "UploadWidget")
    if r1 != 0:
        print(r2)
        return 0
    rsp.ParseFromString(r3)
    return rsp.checkId

# def PublishWidget(widgetid, oss_path):
#     req = aigc_ext_pb2.UploadWidgetReq()
#     req.fileUrl = oss_path

#     rsp = aigc_ext_pb2.UploadWidgetRes()
#     rsp.ParseFromString(_aigc_post(req, "UploadWidget"))
#     return rsp.uploadId
    
def UploadWidgetCheck(checkId):
    req = aigc_ext_pb2.UploadWidgetCheckReq()
    req.version = constant.app_version
    req.checkId = checkId

    rsp = aigc_ext_pb2.UploadWidgetCheckRes()
    r1, r2, r3 = _aigc_post(req, "UploadWidgetCheck")
    if r1 != 0:
        print(r2)
        return 0
    rsp.ParseFromString(r3)
    if rsp.status == aigc_ext_pb2.UploadWidgetStatus.UWS_SUCCESS:
        return 1
    elif rsp.status == aigc_ext_pb2.UploadWidgetStatus.UWS_FAILURE:
        print(f"failReason = {rsp.failReason}")
        return 0
    else:
        return -1
